# Bepr

![bepr (7)](https://user-images.githubusercontent.com/58814900/178315025-2a4233f5-8415-494d-9135-505e031e2e17.png)


[![image](https://img.shields.io/pypi/v/bepr.svg)](https://pypi.python.org/pypi/bepr)
[![image](https://img.shields.io/conda/vn/conda-forge/bepr.svg)](https://anaconda.org/conda-forge/bepr)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


**A python package for modelling Bacteriophage effect on parasitism resistance.**


-   Free software: MIT license
-   Documentation: https://bepr-documentation.readthedocs.io/en/latest/
    

## Features

-   Simulate bacteriophage effect on parasitism resistance;

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
